@@ -27,7 +27,7 @@ def load_pickled_list( local_root_directory= '../data/', list_pkl_file_name = 'm
 
 def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pkl_filename_suffix=None, refetch_all=True,daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None):
     dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
-    pickle_saving_path = local_root_directory+ssj+'_'+dates_stub+'_'+daily_return_pkl_filename_suffix
+    pickle_saving_path = local_root_directory+ssj+'_'+dates_stub+daily_return_pkl_filename_suffix
     if refetch_all:
         year = datetime.datetime.now().year
         month = datetime.datetime.now().month
@@ -107,9 +107,9 @@ def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pk
         dataframe = pd.read_pickle(pickle_saving_path)
     return dataframe
 
-def fetch_crypto_minutely_data(ssj=None, local_root_directory=None, minutely_return_pkl_filename_suffix=None, running_date= None, refetch_all=True):
-    minutes_dates_stub = running_date.strftime('%d_%b_%Y')
-    pickle_saving_path = local_root_directory+ssj+'_'+minutes_dates_stub+'_'+minutely_return_pkl_filename_suffix
+def fetch_crypto_minutely_data(ssj=None, local_root_directory=None, minutely_return_pkl_filename_suffix=None, running_date= None, daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None, refetch_all=True):
+    dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
+    pickle_saving_path = local_root_directory+ssj+'_'+dates_stub+minutely_return_pkl_filename_suffix
     if refetch_all:
         year = datetime.datetime.now().year
         month = datetime.datetime.now().month
@@ -213,7 +213,7 @@ def fetch_crypto_minutely_data(ssj=None, local_root_directory=None, minutely_ret
 
 def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_pkl_filename_suffix=None,refetch_all=True, daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None):
     dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
-    pickle_saving_path = local_root_directory + ssj + '_' + dates_stub + '_' + hourly_return_pkl_filename_suffix
+    pickle_saving_path = local_root_directory + ssj + '_' + dates_stub + hourly_return_pkl_filename_suffix
     if refetch_all:
         year = datetime.datetime.now().year
         month = datetime.datetime.now().month
