@@ -211,7 +211,7 @@ def pair_handling_message(fetcher, msg, compute_minute_signal=True, compute_day_
     volu_dict[trade_time_unix_timestamp_minute] = actual_volu + float(msg['q'])
 
 class RealTimeSignalEnsemblingParalleLauncher():
-    def __init__(self, min_calib_starting_date=None, min_calib_running_date=None, day_calib_starting_date=None, day_calib_running_date=None, drop_token='', dropbox_backup=True, BINANCE_PUBLIC='', BINANCE_SECRET='', AWS_PUBLIC='', AWS_SECRET='', AWS_REGION='',bucket='', local_root_directory='../data',underlying = None, pair = None, min_calib_selected_algo='', day_calib_selected_algo='', user='napoleon',  db_path_suffix = '_run.sqlite', list_pkl_file_suffix = 'my_list.pkl', backed_up_signal_histo_suffix='backed_up_signal_histo.pkl', load_daily_histo = True):
+    def __init__(self, min_calib_starting_date=None, min_calib_running_date=None, day_calib_starting_date=None, day_calib_running_date=None, drop_token='', dropbox_backup=True, BINANCE_PUBLIC='', BINANCE_SECRET='', AWS_PUBLIC='', AWS_SECRET='', AWS_REGION='',bucket='', local_root_directory='../data',underlying = None, pair = None, min_calib_selected_algo='', day_calib_selected_algo='', user='napoleon',  db_path_suffix = '_run.sqlite', list_pkl_file_suffix = 'my_list.pkl', backed_up_signal_histo_suffix='backed_up_signal_histo.pkl', load_daily_histo = True, from_cryptocompare=False):
         self.min_calib_starting_date = min_calib_starting_date
         self.min_calib_running_date = min_calib_running_date
 
@@ -345,8 +345,10 @@ class RealTimeSignalEnsemblingParalleLauncher():
         self.last_minute = None
         self.last_day = None
         self.load_daily_histo = load_daily_histo
+        self.from_cryptocompare = from_cryptocompare
         if self.load_daily_histo:
-            self.reload_daily_histo()
+            print('loading daily historical signals')
+            self.reload_daily_histo(from_cryptocompare = self.from_cryptocompare)
 
 
     def get_aws_last_past_minutes(self, nb_last_hours = 24):
@@ -491,8 +493,8 @@ class RealTimeSignalEnsemblingParalleLauncher():
         print(aggregated_df.shape)
         return aggregated_df
 
-    def recompute_daily_histo(self, from_crypto_compare = False):
-        if from_crypto_compare:
+    def recompute_daily_histo(self, from_cryptocompare = False):
+        if from_cryptocompare:
             print('recomputing historical up to '+str(self.day_max_lookback_window))
             running_date = datetime.now()
             starting_date = running_date - timedelta(days=2*self.day_max_lookback_window)
@@ -570,20 +572,35 @@ class RealTimeSignalEnsemblingParalleLauncher():
         print('saving histo recomputation to '+backed_up_signal_histo_name)
         cumulated_signals.to_pickle(saving_path)
 
-    def reload_daily_histo(self):
+    def reload_daily_histo(self, from_cryptocompare = False):
         upto_date = datetime.now() - timedelta(days=1)
-        backed_up_signal_histo_name =  upto_date.strftime('%d_%b_%Y')+'_'+self.underlying+'_'+self.backed_up_signal_histo_suffix
-        saving_path = self.local_root_directory+backed_up_signal_histo_name
-        print('loading histo recomputation to '+backed_up_signal_histo_name)
-        updated_df = pd.read_pickle(saving_path)
-        updated_df=updated_df.sort_index()
-        signal_columns = [self.day_signal_mapping[me_sig] for me_sig in self.day_calib_signals_list]
-        me_columns = self.generic_columns + signal_columns
-        updated_df = updated_df[me_columns].copy()
-        day_df = updated_df[self.generic_columns].copy()
-        self.day_signal_np = updated_df.values
-        self.day_np = day_df.values
-        self.day_df = day_df
+        if from_cryptocompare :
+            backed_up_signal_histo_name =  upto_date.strftime('%d_%b_%Y')+'_'+self.underlying+'_'+self.backed_up_signal_histo_suffix
+            saving_path = self.local_root_directory+backed_up_signal_histo_name
+            print('loading histo recomputation to '+backed_up_signal_histo_name)
+            updated_df = pd.read_pickle(saving_path)
+            updated_df=updated_df.sort_index()
+            signal_columns = [self.day_signal_mapping[me_sig] for me_sig in self.day_calib_signals_list]
+            me_columns = self.generic_columns + signal_columns
+            updated_df = updated_df[me_columns].copy()
+            day_df = updated_df[self.generic_columns].copy()
+            self.day_signal_np = updated_df.values
+            self.day_np = day_df.values
+            self.day_df = day_df
+        else:
+            updated_df =self.get_aws_last_past_days()
+            updated_df['date'] = pd.to_datetime(updated_df.index)
+            updated_df['ts'] = updated_df['date'].values.astype(np.int64) // 10 ** 9
+            updated_df = updated_df[updated_df.index <= upto_date]
+            updated_df=updated_df.sort_index()
+            signal_columns = [self.day_signal_mapping[me_sig] for me_sig in self.day_calib_signals_list]
+            me_columns = self.generic_columns + signal_columns
+            updated_df = updated_df[me_columns].copy()
+            day_df = updated_df[self.generic_columns].copy()
+            self.day_signal_np = updated_df.values
+            self.day_np = day_df.values
+            self.day_df = day_df
+        return updated_df
 
 
     def start_fetching_pair(self):
